
#####################
#####################
########## HOPKINS and MUMMOLO replication file
#####################
#####################

rm(list=ls())


##set working directory
wd<-"~/Dropbox/framing/TESS/code/qjps_replication"
setwd(wd)
getwd()##check that the working directory was properly assigned



##load packages
library(foreign)
library(polycor)
library(texreg)
library(lmtest)
library(sandwich)
library(xtable)

len<-length
as.c<-as.character
as.n<-as.numeric


# define function to compute var-cov matrix using clustered robust standard errors
# inputs:
# model = model object from call to lm or glm
# cluster = vector with cluster ID indicators
# output:
# cluster robust var-cov matrix
# to call this for a model directly use:
# coeftest(model,vcov = vcovCluster(model, cluster))
# formula is similar to Stata's , cluster command
#
vcovCluster <- function(
                        model,
                        cluster
                        )
  {
require(sandwich)
require(lmtest)
if(nrow(model.matrix(model))!=length(cluster)){
  stop("check your data: cluster variable has different N than model")
}
M <- length(unique(cluster))
N <- length(cluster)           
K <- model$rank   

dfc <- (M/(M - 1)) * ((N - 1)/(N - K))
uj  <- apply(estfun(model), 2, function(x) tapply(x, cluster, sum));
rcse.cov <- dfc * sandwich(model, meat = crossprod(uj)/N)
return(rcse.cov)
}


#################################################################
############
###### ESTIMATION
#############
#################################################################

##load wide data, object name is "dta"
load("dta.Rdata")
##load long data, object name is "dta3"
load("dta3.Rdata")



###### IN-TEXT RESULTS

###compute average number of treated respondents:

##loop over all frame, DV, pairings
counts<-NA
counts1<-NA
counts2<-NA

frames<-c("crime", "terror","stim","health")
dv.names<-c("terror","crime","health","poor","stim")
for(i in 1:length(dv.names)){
	for(j in 1:length(frames)){
	dta$treat<-0
	dta$treat[dta$f.first==frames[j]]<-1
	dta$treat[dta$f.sec==frames[j] & (dta$q3.ord==dv.names[i]|dta$q4.ord==dv.names[i]|dta$q5.ord==dv.names[i])==T]<-1
counts<-c(counts, sum(dta$treat, na.rm=T))
counts1<-c(counts1, sum(dta$treat[dta$f.first==frames[j]]))
counts2<-c(counts2,sum(dta$treat[dta$f.sec==frames[j] & (dta$q3.ord==dv.names[i]|dta$q4.ord==dv.names[i]|dta$q5.ord==dv.names[i])==T]) )
	}
}

print("Mean number of treated respondents")
print(mean(counts, na.rm=T))##mean of 983 respondents treated
print("Mean number of treated respondents after Frame 1")
print(mean(counts1, na.rm=T))##mean of 614 respondents treated after frame 1
print("Mean number of treated respondents after Frame 2")
print(mean(counts2, na.rm=T))##mean of 369 respondents treated after frame 2
print("Number of Control Respondents")
print(table(dta$f.first[dta$f.first=="NOT ASSIGNED"]))##861 control units



###compute polychoric correlations between party and spending variables
print("Polychoric Correlation between Party ID and Spending on Poor")
print(polychor(dta$XPARTY, dta$POORSPND))
print("Polychoric Correlation between Party ID and Spending on Stimulus")
print(polychor(dta$XPARTY, dta$STIMSPND))##largest result
print("Polychoric Correlation between Party ID and Spending on Anti-Crime")
print(polychor(dta$XPARTY, dta$CRMSPND))
print("Polychoric Correlation between Party ID and Spending on Anti-Terror")
print(polychor(dta$XPARTY, dta$TRRSPND))
print("Polychoric Correlation between Party ID and Spending on Health Care")
print(polychor(dta$XPARTY, dta$HLTHSPND))





##################################
##################################
################################## TABLES AND FIGURES
##################################
##################################



########### TABLE 1 / FIGURE 2


### DIRECT EFFECTS OF FRAMES

##main effects

##make matrix to store first set of results
dv.names<-c("CRMSPND","TRRSPND", "POORSPND", "HLTHSPND", "STIMSPND")
frame.names<-c("terror","crime","health","stim")
results<-as.data.frame(matrix(ncol=8, nrow=len(frame.names)*len(dv.names)))
colnames(results)<-c("frame","dv","effect","se","p.val","lb","ub","group")
results$frame<-rep(frame.names,5)
results$group<-rep(1, nrow( results))
results$dv<-c( rep(dv.names[1],4),rep(dv.names[2],4),rep(dv.names[3],4),rep(dv.names[4],4),rep(dv.names[5],4)  )

##the column names below are in the proper order; Q2 = CRMSPND, Q3=TRRSPND, etc

results



		
for (i in 1:len(dv.names)){
		
	
dta.new<-na.omit(dta3[, c("CaseID","score", "treat","strong.rep", "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem","DV")])
	
temp<-dta.new
temp$DV<-factor(temp$DV, levels=dv.names)
table(temp$DV)
levels(temp$DV)##CRMSPND is the omitted category

model<-lm(score~treat+DV+treat*DV+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem,data=temp)
##get clustered SEs
vc<-coeftest(model, vcov.=vca<-vcovCluster(model, cluster=dta.new$CaseID)) 


if(dv.names[i]=="CRMSPND"){
coef<-"treat"

##store effects on crime
results[results$frame=="crime" & results$dv=="CRMSPND", "effect"]<-vc[paste(coef,"crime",sep=""),"Estimate"] 
results[results$frame=="health" & results$dv=="CRMSPND", "effect"]<-vc[paste(coef,"health",sep=""),"Estimate"] 
results[results$frame=="stim" & results$dv=="CRMSPND", "effect"]<-vc[paste(coef,"stim",sep=""),"Estimate"] 
results[results$frame=="terror" & results$dv=="CRMSPND", "effect"]<-vc[paste(coef,"terror",sep=""),"Estimate"] 

##store crime effect SEs
results[results$frame=="crime" & results$dv=="CRMSPND", "se"]<-vc[paste(coef,"crime",sep=""),"Std. Error"] 
results[results$frame=="health" & results$dv=="CRMSPND", "se"]<-vc[paste(coef,"health",sep=""),"Std. Error"] 
results[results$frame=="stim" & results$dv=="CRMSPND", "se"]<-vc[paste(coef,"stim",sep=""),"Std. Error"] 
results[results$frame=="terror" & results$dv=="CRMSPND", "se"]<-vc[paste(coef,"terror",sep=""),"Std. Error"] 

##store crime effect p.vals
results[results$frame=="crime" & results$dv=="CRMSPND", "p.val"]<-vc[paste(coef,"crime",sep=""),"Pr(>|t|)"] 
results[results$frame=="health" & results$dv=="CRMSPND", "p.val"]<-vc[paste(coef,"health",sep=""),"Pr(>|t|)"] 
results[results$frame=="stim" & results$dv=="CRMSPND", "p.val"]<-vc[paste(coef,"stim",sep=""),"Pr(>|t|)"] 
results[results$frame=="terror" & results$dv=="CRMSPND", "p.val"]<-vc[paste(coef,"terror",sep=""),"Pr(>|t|)"] 



}



if(dv.names[i]!="CRMSPND"){
coef<-"treat"

crime1<-paste(coef,"crime",sep="")
crime2<-paste(coef,"crime",":","DV",dv.names[i],sep="")

health1<-paste(coef,"health",sep="")
health2<-paste(coef,"health",":","DV",dv.names[i],sep="")

stim1<-paste(coef,"stim",sep="")
stim2<-paste(coef,"stim",":","DV",dv.names[i],sep="")

terror1<-paste(coef,"terror",sep="")
terror2<-paste(coef,"terror",":","DV",dv.names[i],sep="")

##store effects on other dvs
results[results$frame=="crime" & results$dv==dv.names[i], "effect"]<-num.crime<-vc[crime1,"Estimate"] + vc[crime2,"Estimate"]
results[results$frame=="health" & results$dv==dv.names[i], "effect"]<-num.health<-vc[health1,"Estimate"] + vc[health2,"Estimate"]
results[results$frame=="stim" & results$dv==dv.names[i], "effect"]<-num.stim<-vc[stim1,"Estimate"] + vc[stim2,"Estimate"]
results[results$frame=="terror" & results$dv==dv.names[i], "effect"]<-num.terror<-vc[terror1,"Estimate"] + vc[terror2,"Estimate"]

##store other effect SEs
results[results$frame=="crime" & results$dv==dv.names[i], "se"]<-denom.crime<-sqrt( vca[crime1, crime1 ] + vca[crime2, crime2] + 2*vca[crime1, crime2])

results[results$frame=="health" & results$dv==dv.names[i], "se"]<-denom.health<-sqrt( vca[health1, health1 ] + vca[health2, health2] + 2*vca[health1, health2])

results[results$frame=="stim" & results$dv==dv.names[i], "se"]<-denom.stim<-sqrt( vca[stim1, stim1 ] + vca[stim2, stim2] + 2*vca[stim1, stim2])

results[results$frame=="terror" & results$dv==dv.names[i], "se"]<-denom.terror<-sqrt( vca[terror1, terror1 ] + vca[terror2, terror2] + 2*vca[terror1, terror2])


t.crime<-num.crime/denom.crime
t.health<-num.health/denom.health
t.stim<-num.stim/denom.stim
t.terror<-num.terror/denom.terror


##store other effect p.vals
results[results$frame=="crime" & results$dv==dv.names[i], "p.val"]<-2*pnorm(abs(t.crime), lower.tail=F)
results[results$frame=="health" & results$dv==dv.names[i], "p.val"]<-2*pnorm(abs(t.health), lower.tail=F)
results[results$frame=="stim" & results$dv==dv.names[i], "p.val"]<-2*pnorm(abs(t.stim), lower.tail=F)
results[results$frame=="terror" & results$dv==dv.names[i], "p.val"]<-2*pnorm(abs(t.terror), lower.tail=F)




       }

  
  #store effect CIs
results$lb<- results$effect-1.96*results$se
results$ub<- results$effect+1.96*results$se
results$one.se.lb<- results$effect-results$se
results$one.se.ub<- results$effect+results$se



}


results$frame<-c("Terrorism\nFrame","Crime\nFrame","Health\nFrame","Stimulus\nFrame")


effects<-results

##save results as an R data frame

file.name<-"output/effects.Rdata"
save(effects, file=file.name)




################
###### TABLE 1
################

##make table of regression output
	dta.new<-na.omit(dta3[, c("CaseID","score", "treat","strong.rep", "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem","DV")])

m1<-lm(score~treat+DV+treat*DV+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem,data= dta.new)
##get clustered SEs
vc<-coeftest(m1, vcov.=vca<-vcovCluster(m1, cluster= dta.new$CaseID)) 
vc
table1<-texreg(vc,single.row=T,stars=c(0.05))


##Save Table 1 to working directory
cat(table1, file="output/table1.tex")

##Save numeric results as R dataframe
file.name<-"output/effects_regression_output.Rdata"
save(vc, file=file.name)


print("Table 1 saved")




#################
####### FIGURE 2: this will output a file called "figure2.pdf"
#################
load("output/effects.Rdata")



terror<-subset(effects, effects$frame=="Terrorism\nFrame")
crime<-subset(effects, effects$frame=="Crime\nFrame")
health<-subset(effects, effects$frame=="Health\nFrame")
stim<-subset(effects, effects$frame=="Stimulus\nFrame")

frame.res<-list(terror, crime, health, stim)
names(frame.res)<-c("terror","crime","health","stim")


y.min<-NA
y.max<-NA

for(i in 1:length(frame.res)){
	rownames(frame.res[[i]])<-frame.res[[i]]$dv
		
	frame.res[[i]]$bar.names<-NA
	frame.res[[i]]$bar.names[frame.res[[i]]$dv=="TRRSPND"]<-"Increase\nAnti-Terrorism\nSpending"
	frame.res[[i]]$bar.names[frame.res[[i]]$dv=="CRMSPND"]<-"Increase\nAnti-Crime\nSpending"
	frame.res[[i]]$bar.names[frame.res[[i]]$dv=="POORSPND"]<-"Decresae\nAnti-Poverty\nSpending"
	frame.res[[i]]$bar.names[frame.res[[i]]$dv=="HLTHSPND"]<-"Decrease\nHealth Care\nSpending"
	frame.res[[i]]$bar.names[frame.res[[i]]$dv=="STIMSPND"]<-"Decrease\nStimulus\nSpending"
	
frame.res[[i]]$p.val2<-round(frame.res[[i]]$p.val,2)
frame.res[[i]]$p.val2[ frame.res[[i]]$p.val2 <.01 ]<-"<0.01"
frame.res[[i]]$p.val2[ frame.res[[i]]$p.val2 >=.01 ]<-paste("=",frame.res[[i]]$p.val2[ frame.res[[i]]$p.val2 >=.01 ],sep="")

y.min<-c(y.min, min(frame.res[[i]]$lb))
y.max<-c(y.max, max(frame.res[[i]]$ub))



}


y.min2<-min(y.min, na.rm=T)
y.max2<-max(y.max, na.rm=T)



##order results within each frame
frame.res[["terror"]]<-frame.res[["terror"]][c("TRRSPND","CRMSPND","POORSPND","STIMSPND","HLTHSPND"),]
frame.res[["crime"]]<-frame.res[["crime"]][c("CRMSPND","TRRSPND","POORSPND","STIMSPND","HLTHSPND"),]
frame.res[["health"]]<-frame.res[["health"]][c("HLTHSPND","STIMSPND","POORSPND","CRMSPND","TRRSPND"),]
frame.res[["stim"]]<-frame.res[["stim"]][c("STIMSPND","HLTHSPND","POORSPND","CRMSPND","TRRSPND"),]


plot.names<-c("Terrorism Frame","Crime Frame","Health Care Frame","Stimulus Frame")

pdf("output/figure2.pdf", width=9, height=7)

par(mfrow=c(2,2))
for(i in 1:length(frame.res)){

bar<-barplot(frame.res[[i]]$effect,  main=plot.names[i], 
col="gray", xlab="",  horiz=FALSE, 
names.arg=frame.res[[i]]$bar.names ,axes=F,
   ylab="Effect (Percentage Points)", 
   border="black" , las=1 ,xlim=c(0,6),
 ylim=c(y.min2-3, y.max2) ,  axis.lty = 0,
   cex.names=.65, cex=1.2, cex.main=1.2, cex.axis=1)
  abline(h=0)
  segments(bar,frame.res[[i]]$lb, bar, frame.res[[i]]$ub ) ##center CIs over each bar
    segments(bar,frame.res[[i]]$one.se.lb, bar, frame.res[[i]]$one.se.ub, lwd=3 ) ##center one SE above/below

axis(2, at=seq(-100,100,2), tck=-.03, cex=.2, labels=T, las=2)
#text(x=bar, y=-9, labels=paste("p=",signif(frame.res[[i]]$p.val,digits=2),sep="") , cex=.7)
text(x=bar, y=y.min2-1, labels=paste("p", frame.res[[i]]$p.val2, "\nSE=",round(frame.res[[i]]$se,digits=2)  ,  sep="") , cex=.7)

}

dev.off()




print("Figure 2 saved")







#########################
############## FIGURE 3: will produce a file called "figure3.pdf" (also produces Appendix Figures 5 and 6 using alternate treatment specifications)
#########################


#################################################################
### Effects of frames on direct spending outcome relative to effects of same frames on distant-spending outcomes
#################################################################


##make matrix to store first set of results
dv.names<-c("TRRSPND", "CRMSPND", "HLTHSPND", "STIMSPND","POORSPND")
frame.names<-c("terror","crime","health","stim")
direct.dvs<-c("TRRSPND", "CRMSPND", "HLTHSPND", "STIMSPND")
ref<-dv.names##reference spending category

orders<-list(c("CRMSPND","STIMSPND","HLTHSPND","POORSPND"),  c("TRRSPND","STIMSPND","HLTHSPND","POORSPND"), c("STIMSPND","POORSPND","CRMSPND","TRRSPND"),c("HLTHSPND","POORSPND","CRMSPND","TRRSPND"))

results<-as.data.frame(matrix(ncol=7, nrow=4))
colnames(results)<-c("frame","dv","effect","se","p.val","lb","ub")

res<-list(results, results, results, results)##make one storage object for each frame

parties<-c("all", paste(c("all"), ".first.frame",sep=""),paste(c("all"), ".first2",sep=""))

res.party<-list(res, res, res)##make one storage object for each subgroup
names(res.party)<-parties



dta3$all<-1

##group indicators
groups<-c("all","all","all")
           ##values needed to activiate group indicators
val<-c(1,1,1)


for(k in 1:length(parties)){##loop over subgroups
	
	##define version of treatment needed
	if(length(grep("first", names(res.party)[k]))==0){
	version<-1
	dta.new<-na.omit(dta3[dta3[,groups[k]]==val[k], c("CaseID","score", "treat","strong.rep", "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem","DV")])
	dim(dta.new)
	}
	
	if(length(grep("first.frame", names(res.party)[k]))>0){
	version<-2
dta.new<-na.omit(dta3[dta3[,groups[k]]==val[k], c("CaseID","score", "treat2","strong.rep", "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem","DV")])
dta.new$treat<-dta.new$treat2
	}

	if(length(grep("first2", names(res.party)[k]))>0){
	version<-3
	dta.new<-na.omit(dta3[dta3[,groups[k]]==val[k], c("CaseID","score", "treat3","strong.rep", "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem","DV")])
	dta.new$treat<-dta.new$treat3

	}
	
	


for (i in 1:len(frame.names)){ ##loop over DVs

	
res.party[[k]][[i]]$frame<-frame.names[i]
res.party[[k]][[i]]$dv<-dv.names[dv.names!=dv.names[i]]


rownames(res.party[[k]][[i]])<-res.party[[k]][[i]]$dv ##assign rownames
res.party[[k]][[i]]<-res.party[[k]][[i]][orders[[i]],] ##order

	
##make appropropriate reference category be the first level (the directly related outcome)
dta.new$DV<-factor(dta.new$DV, levels=c(direct.dvs[i],  dv.names[dv.names!= direct.dvs[i]] ) )
levels(dta.new$DV)


model<-lm(score~treat+DV+treat*DV+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem, data=dta.new)
summary(model)

vc<-coeftest(model, vcov.=vcovCluster(model, cluster=dta.new$CaseID))


##store effects
##get name of coef for diff in diff
for(j in 1:nrow(res.party[[k]][[i]])){

coef<-paste("treat",frame.names[i],":", "DV",rownames(res.party[[k]][[i]])[j],sep="")
res.party[[k]][[i]]$effect[j]<-vc[coef,"Estimate"]
res.party[[k]][[i]]$se[j]<-vc[coef,"Std. Error"]
res.party[[k]][[i]]$p.val[j]<-vc[coef,"Pr(>|t|)"]


}

res.party[[k]][[i]]$dv.name[ res.party[[k]][[i]]$dv=="CRMSPND" ]<-"Crime\nSpending"
res.party[[k]][[i]]$dv.name[ res.party[[k]][[i]]$dv=="TRRSPND" ]<-"Terror\nSpending"
res.party[[k]][[i]]$dv.name[ res.party[[k]][[i]]$dv=="POORSPND" ]<-"Poor\nSpending"
res.party[[k]][[i]]$dv.name[ res.party[[k]][[i]]$dv=="HLTHSPND" ]<-"Health\nSpending"
res.party[[k]][[i]]$dv.name[ res.party[[k]][[i]]$dv=="STIMSPND" ]<-"Stim\nSpending"

res.party[[k]][[i]]$frame[ res.party[[k]][[i]]$frame=="crime" ]<-"Crime\nFrame"
res.party[[k]][[i]]$frame[ res.party[[k]][[i]]$frame=="terror" ]<-"Terror\nFrame"
res.party[[k]][[i]]$frame[ res.party[[k]][[i]]$frame=="health" ]<-"Health\nFrame"
res.party[[k]][[i]]$frame[ res.party[[k]][[i]]$frame=="stim" ]<-"Stimulus\nFrame"


res.party[[k]][[i]]$lb<-res.party[[k]][[i]]$effect-1.96*res.party[[k]][[i]]$se
res.party[[k]][[i]]$ub<-res.party[[k]][[i]]$effect+1.96*res.party[[k]][[i]]$se
res.party[[k]][[i]]$one.se.lb<-res.party[[k]][[i]]$effect-res.party[[k]][[i]]$se
res.party[[k]][[i]]$one.se.ub<-res.party[[k]][[i]]$effect+res.party[[k]][[i]]$se


names(res.party[[k]])[i]<-frame.names[i]

}
}

res.party

  
##save results as an R data frame

file.name<-"output/effects_relative_frame_org.Rdata"
save(res.party, file=file.name)




###plots organized by frame


plot.names<-c("Terror Frame","Crime Frame","Health Care Frame","Stimulus Frame")

y.labs<-c("Difference from Effect\non Terror $ (Percentage Points)", "Difference from Effect\non Crime $ (Percentage Points)","Difference from Effect\non Health Care $ (Percentage Points)", "Difference from Effect\non Stimulus $ (Percentage Points)"  )

for(k in 1:length(parties)){

pre<-"/Users/jonathanmummolo/Dropbox/framing/"
pdf(paste(c("output/figure3","output/figure5","output/figure6")[k],".pdf",sep=""), width=8, height=7)



par(mfrow=c(2,2), mar=c(3,5,3,3))

##get limits for y axis
min.k<-NA
max.k<-NA
for(j in 1:4){
	
	min.k[j]<-min(res.party[[k]][[j]]$lb)
	max.k[j]<-max(res.party[[k]][[j]]$ub)

res.party[[k]][[j]]$p.val2<-round(res.party[[k]][[j]]$p.val,2)
res.party[[k]][[j]]$p.val2[ res.party[[k]][[j]]$p.val2 <.01 ]<-"<0.01"
res.party[[k]][[j]]$p.val2[ res.party[[k]][[j]]$p.val2 >=.01 ]<-paste("=",res.party[[k]][[j]]$p.val2[ res.party[[k]][[j]]$p.val2 >=.01 ],sep="")

	
}
min.k2<-min(min.k)
max.k2<-max(max.k)

for(i in 1:4){

bar<-barplot(res.party[[k]][[i]]$effect,  main=plot.names[i], col="gray", xlab="",  horiz=FALSE, 
names.arg= res.party[[k]][[i]]$dv.name ,axes=F, ylab=y.labs[i], border="black" , las=1 ,xlim=c(0, 5), ylim=c(min.k2-4 , max.k2 ) ,  axis.lty = 0,cex.names=.68, cex=1.2, cex.main=1.2, cex.axis=1)
  abline(h=0)
  segments(bar,res.party[[k]][[i]]$lb, bar, res.party[[k]][[i]]$ub ) ##center CIs over each bar
    segments(bar,res.party[[k]][[i]]$one.se.lb, bar, res.party[[k]][[i]]$one.se.ub, lwd=3 ) ##center CIs over each bar
text(x=bar, y=min.k2-2, labels=paste("p",res.party[[k]][[i]]$p.val2,"\nSE=",round(res.party[[k]][[i]]$se,digits=2),sep=""), cex=.7)
axis(2, at=seq(-100,100,5), tck=-.03, cex=.2, labels=T, las=2)

}


dev.off()

}





print("Figures 3, 5 and 6 saved")



############################
############################
############################ APPENDIX
############################
############################
############################


####TABLE 3

means<-NA
sds<-NA
vars<-c("CRMSPND","TRRSPND","POORSPND","HLTHSPND","STIMSPND")
labs<-c("Anti-Crime Spending","Anti-Terror Spending","Anti-Poverty Spending","Health Care Spending","Stimulus Spending")

for(i in 1:length(vars)){
	
	means[i]<-mean(dta[dta$f.first =="NOT ASSIGNED",vars[i]], na.rm=T)
	sds[i]<-sd(dta[dta$f.first =="NOT ASSIGNED",vars[i]], na.rm=T)
	
}

res<-cbind.data.frame(mean=means, sd=sds)
rownames(res)<-labs
table3<-round(res, digits=2)
table3

file.name<-"output/table3.Rdata"
save(table3, file=file.name)
table3b<-print(xtable(table3))
cat(table3b, file="output/table3.tex")


print("Table 3 saved")



############# TABLE 4

convince<-NA
within<-NA
table(dta$Q1SUM, exclude=NULL)
##use wide data to determine share of respondents that find frames convincing
dta$Q1SUM_2<-NA
dta$Q1SUM_2[dta$Q1SUM=="No"]<-0
dta$Q1SUM_2[dta$Q1SUM=="Unsure"]<-NA
dta$Q1SUM_2[dta$Q1SUM=="Yes"]<-1
table(dta$Q1SUM_2, exclude=NULL)

##put these vectors in same order:
frames<-c("crime", "terror","stim","health")
dv.names<-c("CRMSPND","TRRSPND", "STIMSPND","HLTHSPND","POORSPND")

for(i in 1:length(frames)){
	
	convince[i]<-mean(dta$Q1SUM_2[dta$f.first==frames[i]], na.rm=T)*100
	temp<-na.omit(dta3[, c("CaseID","score","treat","strong.rep", "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem","DV")])
	print(table(temp$treat))
	dim(temp)

temp$DV<-factor(temp$DV, levels=dv.names)
table(temp$DV)
levels(temp$DV)##CRMSPND is the omitted category

	m<-lm(score~treat+DV+treat*DV+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem,data=temp)	
	
	if(dv.names[i]=="CRMSPND"){
	coef<-paste("treat",frames[i],sep="")
	within[i]<-m$coefficients[coef]
	}

	if(dv.names[i]!="CRMSPND"){
	coef1<-paste("treat",frames[i],sep="")
	coef2<-paste("treat",frames[i],":","DV",dv.names[i],sep="")
	within[i]<-m$coefficients[coef1] + m$coefficients[coef2] 
	}	
	
	
}

table4<-cbind.data.frame(frames, pct.convince=convince, within.effect=within)
table4[,2:3]<-round(table4[,2:3], digits=2)
table4

file.name<-"output/table4.Rdata"
save(table4, file=file.name)
table4b<-print(xtable(table4))
cat(table4b, file="output/table4.tex")



print("Table 4 saved")


#####FIGURE 4: effects organized by spending outcome
load("output/effects.Rdata")

	
effects$frame[effects
$frame=="Terrorism Frame"]<-"Terrorism\nFrame"
effects$frame[effects
$frame=="Crime Frame"]<-"Crime\nFrame"
effects$frame[effects
$frame=="Health Frame"]<-"Health\nFrame"
effects$frame[effects
$frame=="Stim Frame"]<-"Stimulus\nFrame"


## crime DV
crime<-subset(effects,  effects$dv=="CRMSPND")
crime

crime$order<-NA
crime$order[crime$frame=="Crime\nFrame"]<-1
crime$order[crime$frame=="Terrorism\nFrame"]<-2
crime$order[crime$frame=="Stimulus\nFrame"]<-4
crime$order[crime$frame=="Health\nFrame"]<-3
crime<-crime[order(crime$order),]
crime

##terror DV
terror<-subset(effects,  effects$dv=="TRRSPND")
terror

terror$order<-NA
terror$order[terror$frame=="Crime\nFrame"]<-2
terror$order[terror$frame=="Terrorism\nFrame"]<-1
terror$order[terror$frame=="Stimulus\nFrame"]<-4
terror$order[terror$frame=="Health\nFrame"]<-3
terror<-terror[order(terror$order),]
terror

## poor DV
poor<-subset(effects,  effects$dv=="POORSPND")

poor$order<-NA
poor$order[poor$frame=="Crime\nFrame"]<-3
poor$order[poor$frame=="Terrorism\nFrame"]<-4
poor$order[poor$frame=="Stimulus\nFrame"]<-1
poor$order[poor$frame=="Health\nFrame"]<-2
poor<-poor[order(poor$order),]
poor

##health DV
health<-subset(effects,  effects$dv=="HLTHSPND")

health$order<-NA
health$order[health$frame=="Crime\nFrame"]<-3
health$order[health$frame=="Terrorism\nFrame"]<-4
health$order[health$frame=="Stimulus\nFrame"]<-2
health$order[health$frame=="Health\nFrame"]<-1
health<-health[order(health$order),]
health


## stim DV
stim<-subset(effects,  effects$dv=="STIMSPND")

stim$order<-NA
stim$order[stim$frame=="Crime\nFrame"]<-3
stim$order[stim$frame=="Terrorism\nFrame"]<-4
stim$order[stim$frame=="Stimulus\nFrame"]<-1
stim$order[stim$frame=="Health\nFrame"]<-2
stim<-stim[order(stim$order),]
stim



#crime terror poor health stim

##### make pooled bar graph

res2<-list(terror, crime, poor, health, stim)
titles<-c("Increase\nAnti-Terror Spending","Increase\nAnti-Crime Spending","Decrease\nAnti-Poverty Spending","Decrease\nHealth Care Spending","Decrease\nStimulus Spending")



y.min<-NA
y.max<-NA
for(j in 1:length(res2)){
	res2[[j]]<-res2[[j]][order(res2[[j]]$order,decreasing=F),]
	
res2[[j]]$p.val2<-round(res2[[j]]$p.val,2)
res2[[j]]$p.val2[ res2[[j]]$p.val2 <.01 ]<-"<0.01"
res2[[j]]$p.val2[ res2[[j]]$p.val2 >=.01 ]<-paste("=",res2[[j]]$p.val2[ res2[[j]]$p.val2 >=.01 ],sep="")

y.min<-c(y.min, min(res2[[j]]$lb))
y.max<-c(y.max, max(res2[[j]]$ub))



}

y.min2<-min(y.min, na.rm=T)
y.max2<-max(y.max, na.rm=T)



pdf(paste("output/figure4",".pdf",sep=""), width=8, height=5)

par(mfrow=c(2,3), mar=c(2,5,3,1))

for(i in 1:length(res2)){
bar<-barplot(res2[[i]]$effect,  main=titles[i], 
col="gray", xlab="",  horiz=FALSE, 
names.arg=res2[[i]]$frame ,axes=F,
   ylab="Effect (Percentage Points)", 
   border="black" , las=1 ,xlim=c(0,5),
 ylim=c(y.min2-3,y.max2) ,  axis.lty = 0,
   cex.names=.82, cex=1.2, cex.main=1.2, cex.axis=1)
  abline(h=0)
  segments(bar,res2[[i]]$lb, bar, res2[[i]]$ub ) ##center CIs over each bar
    segments(bar,res2[[i]]$one.se.lb, bar, res2[[i]]$one.se.ub, lwd=3 ) ##one SE over each bar
axis(2, at=seq(-1,1,.2)*10, tck=-.03, cex=.2, labels=T, las=2)
text(x=bar, y=y.min2-2, labels=paste("p",res2[[i]]$p.val2, "\nSE=",round(res2[[i]]$se,digits=2)  ,  sep="") , cex=.7)
}

dev.off()


print("Figure 4 saved")





##########################
######### FIGURES 5 and 6
##########################


### These figures have already been produced when Figure 3 was generated above. The file names are "effects_frame_org_relative_all.first.frame_.pdf" and "effects_frame_org_relative_all.first2_.pdf" saved in the "output" folder.





##########################
########## FIGURE 7
##########################

######## POOLED RESULTS




##direct v. distant (a)
pooled.names<-c("direct_v_distant_a","direct_v_distant_b", "direct_v_proximate","prox_v_two_most_distant" )
res<-cbind.data.frame(pooled.names)
res$did<-NA
res$se<-NA
res$lb<-NA
res$ub<-NA
res$t.stat<-NA
res$p.val<-NA
res

dta.direct<-dta3


##restrict to commonly used DVs
dta.direct $DV2<-NA
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED"& dta.direct $DV=="TRRSPND"]<-"control"
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED"& dta.direct $DV=="STIMSPND"]<-"control"

dta.direct$DV2[dta.direct $treat=="terror" & dta.direct$DV=="TRRSPND"]<-"direct"
dta.direct$DV2[dta.direct $treat=="stim" & dta.direct$DV=="STIMSPND"]<-"direct"

dta.direct $DV2[dta.direct $treat=="crime" & dta.direct $DV=="STIMSPND"]<-"distant"
dta.direct $DV2[dta.direct $treat=="terror" & dta.direct $DV=="STIMSPND"]<-"distant"
dta.direct $DV2[dta.direct $treat=="health" & dta.direct $DV=="TRRSPND"]<-"distant"
dta.direct $DV2[dta.direct $treat=="stim" & dta.direct $DV=="TRRSPND"]<-"distant"
table(dta.direct $DV2, exclude=NULL)


dta.direct $DV2<-factor(dta.direct $DV2, levels=c("control","direct","distant"))
table(dta.direct $DV2)


temp1<-na.omit(dta.direct[,c("CaseID","DV2","score","strong.rep" , "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem")])

summary(m1<-lm(score~DV2+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem, data=temp1))

vc1<-coeftest(m1, vcov.=vca<-vcovCluster(m1, cluster=temp1$CaseID))


#get diff in diff
did<-vc1["DV2direct","Estimate"] - vc1["DV2distant","Estimate"]
se<-sqrt( vca["DV2direct","DV2direct"] + vca["DV2distant","DV2distant"] - 2*vca["DV2distant","DV2direct"] )
lb<-did-1.96*se
ub<-did+1.96*se
did
lb
ub
t.stat<-abs(did/se)
p.val<-2*pnorm(abs(t.stat), lower.tail=F)
res$did[res$pooled.names=="direct_v_distant_a"]<-did
res$se[res$pooled.names=="direct_v_distant_a"]<-se
res$lb[res$pooled.names=="direct_v_distant_a"]<-lb
res$ub[res$pooled.names=="direct_v_distant_a"]<-ub
res$t.stat[res$pooled.names=="direct_v_distant_a"]<-t.stat
res$p.val[res$pooled.names=="direct_v_distant_a"]<-p.val
res



#################
###direct v. distant (b)

dta.direct<-dta3

dta.direct $DV2<-NA
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED" & dta.direct $DV=="CRMSPND"]<-"control"
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED"& dta.direct $DV=="HLTHSPND"]<-"control"

dta.direct$DV2[dta.direct $treat=="crime" & dta.direct$DV=="CRMSPND"]<-"direct"
dta.direct$DV2[dta.direct $treat=="health" & dta.direct$DV=="HLTHSPND"]<-"direct"


dta.direct $DV2[dta.direct $treat=="crime" & dta.direct $DV=="HLTHSPND"]<-"distant"
dta.direct $DV2[dta.direct $treat=="terror" & dta.direct $DV=="HLTHSPND"]<-"distant"
dta.direct $DV2[dta.direct $treat=="health" & dta.direct $DV=="CRMSPND"]<-"distant"
dta.direct $DV2[dta.direct $treat=="stim" & dta.direct $DV=="CRMSPND"]<-"distant"
table(dta.direct $DV2, exclude=NULL)

dta.direct $DV2<-factor(dta.direct $DV2, levels=c("control","direct","distant"))
table(dta.direct $DV2)


temp1<-na.omit(dta.direct[,c("CaseID","DV2","score","strong.rep" , "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem")])

summary(m1<-lm(score~DV2+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem, data=temp1))

vc1<-coeftest(m1, vcov.=vca<-vcovCluster(m1, cluster=temp1$CaseID))


#get diff in diff
did<-vc1["DV2direct","Estimate"] - vc1["DV2distant","Estimate"]
se<-sqrt( vca["DV2direct","DV2direct"] + vca["DV2distant","DV2distant"] - 2*vca["DV2distant","DV2direct"] )
lb<-did-1.96*se
ub<-did+1.96*se
did
lb
ub
t.stat<-abs(did/se)
p.val<-2*pnorm(abs(t.stat), lower.tail=F)
res$did[res$pooled.names=="direct_v_distant_b"]<-did
res$se[res$pooled.names=="direct_v_distant_b"]<-se
res$lb[res$pooled.names=="direct_v_distant_b"]<-lb
res$ub[res$pooled.names=="direct_v_distant_b"]<-ub
res$t.stat[res$pooled.names=="direct_v_distant_b"]<-t.stat
res$p.val[res$pooled.names=="direct_v_distant_b"]<-p.val
res



#################
### proximate

dta.direct<-dta3

dta.direct $DV2<-NA
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED" & dta.direct $DV=="CRMSPND"]<-"control"
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED"& dta.direct $DV=="TRRSPND"]<-"control"
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED"& dta.direct $DV=="HLTHSPND"]<-"control"
dta.direct $DV2[dta.direct $treat=="NOT ASSIGNED"& dta.direct $DV=="STIMSPND"]<-"control"

dta.direct$DV2[dta.direct $treat=="crime" & dta.direct$DV=="CRMSPND"]<-"direct"
dta.direct$DV2[dta.direct $treat=="terror" & dta.direct$DV=="TRRSPND"]<-"direct"
dta.direct$DV2[dta.direct $treat=="health" & dta.direct$DV=="HLTHSPND"]<-"direct"
dta.direct$DV2[dta.direct $treat=="stim" & dta.direct$DV=="STIMSPND"]<-"direct"

dta.direct $DV2[dta.direct $treat=="crime" & dta.direct $DV=="TRRSPND"]<-"prox"
dta.direct $DV2[dta.direct $treat=="terror" & dta.direct $DV=="CRMSPND"]<-"prox"
dta.direct $DV2[dta.direct $treat=="health" & dta.direct $DV=="STIMSPND"]<-"prox"
dta.direct $DV2[dta.direct $treat=="stim" & dta.direct $DV=="HLTHSPND"]<-"prox"
table(dta.direct$DV2, exclude=NULL)

dta.direct $DV2<-factor(dta.direct $DV2, levels=c("control","direct","prox"))
table(dta.direct $DV2)


temp1<-na.omit(dta.direct[,c("CaseID","DV2","score","strong.rep" , "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem")])


summary(m1<-lm(score~DV2+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem, data=temp1))

vc1<-coeftest(m1, vcov.=vca<-vcovCluster(m1, cluster=temp1$CaseID))


#get diff in diff
did<-vc1["DV2direct","Estimate"] - vc1["DV2prox","Estimate"]
se<-sqrt( vca["DV2direct","DV2direct"] + vca["DV2prox","DV2prox"] - 2*vca["DV2direct","DV2prox"]  )
lb<-did-1.96*se
ub<-did+1.96*se
did
lb
ub
t.stat<-abs(did/se)
p.val<-2*pnorm(abs(t.stat), lower.tail=F)
res$did[res$pooled.names=="direct_v_proximate"]<-did
res$se[res$pooled.names=="direct_v_proximate"]<-se
res$lb[res$pooled.names=="direct_v_proximate"]<-lb
res$ub[res$pooled.names=="direct_v_proximate"]<-ub
res$t.stat[res$pooled.names=="direct_v_proximate"]<-t.stat
res$p.val[res$pooled.names=="direct_v_proximate"]<-p.val
res





#################
### prox v. two most distant

dta.prox<-dta3

dta.prox $DV2<-NA
dta.prox $DV2[dta.prox $treat=="NOT ASSIGNED"& dta.prox $DV=="HLTHSPND"]<-"control"
dta.prox $DV2[dta.prox $treat=="NOT ASSIGNED"& dta.prox $DV=="CRMSPND"]<-"control"
dta.prox $DV2[dta.prox $treat=="NOT ASSIGNED"& dta.prox $DV=="TRRSPND"]<-"control"
dta.prox $DV2[dta.prox $treat=="NOT ASSIGNED"& dta.prox $DV=="STIMSPND"]<-"control"

dta.prox $DV2[dta.prox $treat=="crime" & dta.prox $DV=="TRRSPND"]<-"prox"
dta.prox $DV2[dta.prox $treat=="terror" & dta.prox $DV=="CRMSPND"]<-"prox"
dta.prox $DV2[dta.prox $treat=="health" & dta.prox $DV=="STIMSPND"]<-"prox"
dta.prox $DV2[dta.prox $treat=="stim" & dta.prox $DV=="HLTHSPND"]<-"prox"
table(dta.prox$DV2, exclude=NULL)



dta.prox $DV2[dta.prox $treat=="crime" & dta.prox $DV=="HLTHSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="crime" & dta.prox $DV=="STIMSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="terror" & dta.prox $DV=="HLTHSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="terror" & dta.prox $DV=="STIMSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="health" & dta.prox $DV=="CRMSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="health" & dta.prox $DV=="TRRSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="stim" & dta.prox $DV=="CRMSPND"]<-"distant"
dta.prox $DV2[dta.prox $treat=="stim" & dta.prox $DV=="TRRSPND"]<-"distant"
table(dta.prox $DV2, exclude=NULL)


dta.prox $DV2<-factor(dta.prox $DV2, levels=c("control","prox","distant"))
table(dta.prox $DV2)


temp1<-na.omit(dta.prox[,c("CaseID","DV2","score","strong.rep" , "weak.rep" , "lean.rep" , "strong.dem" , "weak.dem" , "lean.dem")])

summary(m1<-lm(score~DV2+strong.rep +weak.rep + lean.rep + strong.dem + weak.dem + lean.dem, data=temp1))

vc1<-coeftest(m1, vcov.=vca<-vcovCluster(m1, cluster=temp1$CaseID))


#get diff in diff
did<-vc1["DV2prox","Estimate"] - vc1["DV2distant","Estimate"]
se<-sqrt( vca["DV2prox","DV2prox"] + vca["DV2distant","DV2distant"] - 2*vca["DV2distant","DV2prox"] )
lb<-did-1.96*se
ub<-did+1.96*se
did
lb
ub
t.stat<-abs(did/se)
p.val<-2*pnorm(abs(t.stat), lower.tail=F)
res$did[res$pooled.names=="prox_v_two_most_distant"]<-did
res$se[res$pooled.names=="prox_v_two_most_distant"]<-se
res$lb[res$pooled.names=="prox_v_two_most_distant"]<-lb
res$ub[res$pooled.names=="prox_v_two_most_distant"]<-ub
res$t.stat[res$pooled.names=="prox_v_two_most_distant"]<-t.stat
res$p.val[res$pooled.names=="prox_v_two_most_distant"]<-p.val
res

res$p.val2<-round(res$p.val, digits=2)
res$p.val2[res$p.val2<.01]<-"<.01"
res$p.val2[res$p.val2>=.01]<-paste("=",res$p.val2[res$p.val2>=.01],sep="")
res

pdf("output/figure7.pdf", width=8, height=5)
par(mar=c(4,6,4,4))
bar<-barplot(res$did,  main="Differences in Framing Effects by\n Proximity of Frames to DVs", 
col="gray", xlab="",  horiz=FALSE, 
names.arg=c("Direct v.\nDistant (a)","Direct v.\nDistant (b)", "Direct v.\nProximate", "Proximate v. Two\nMost Distant" ) ,axes=F,
   ylab="Difference in Effects\n(Percentage Points)", 
   border="black" , las=1 ,xlim=c(0,5),
 ylim=c(-2,8) ,  axis.lty = 0,
   cex.names=.82, cex=1.2, cex.main=1.2, cex.axis=1)
  abline(h=0)
  segments(bar,res$lb, bar, res$ub ) ##center CIs over each bar
    segments(bar,res$did-res$se, bar,res$did+res$se, lwd=3 ) ##one SE over each bar
axis(2, at=seq(-1,1,.2)*10, tck=-.03, cex=.2, labels=T, las=2)
text(x=bar, y=-1.5, labels=paste("p",res$p.val2,"\nSE=",round(res$se,digits=2),sep="") , cex=.7)
dev.off()

print("Figure 7 saved")